function hillbasal
% HILLBASAL.M
%
% Code to study dx/dt = Ax/(h+x) + B - delta*x 
%
% First three subfunctions are defined which can see the 
% parameters in the enclosing function HILL. 
% Then the graphs are plotted and numerical simulations carried out. 
%
% QUESTION: What happens as you increase delta? 
% To explore this, edit the value of delta and re-run. 

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % function defining Ax/(h+x)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    function Pfun = P(x)
        Pfun = A*x.^n./(h^n+x.^n) + B;
    end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % function defining dx/dt 
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    function f = dxdt(x)
        f = P(x) - delta*x;
    end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % function defining dx/dt 
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    function f = dxdtode(t,x)
        f = dxdt(x);
    end

% initialise parameters and the range of x
xmin = 0;
xmax = 1.2;
A = 1;
h = 0.5;
delta = 1.2;
n = 4;
B = 0.0;
% generate a string containing the parameter values for figures
param_string = sprintf('A=%g, B=%g, h=%g, n=%d, \\delta=%g',A,B,h,n,delta);

% initialise figure(1)
figure(1), clf, hold on
% initialise figure(2)
figure(2), clf, hold on
% initialise figure(3)
figure(3), clf, hold on

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% steady states are where dx/dt = 0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
xss = fzero(@dxdt,1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1. Plot P(x)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% set up a vector of x values 
x = xmin:0.01:xmax;
% plots to go on figure(1)
figure(1)
% plot Px/(h+x)
plot(x,P(x),'k-','linewidth',2)
% Superimpose delta*x
plot(x,delta*x,'k--','linewidth',2)
% the intersection should be at (xss,P(xss))
plot(xss,P(xss),'*','markersize',10)
% set the axes labels to be larger
set(gca,'fontsize',14)
% add some axes labels
xlabel('x')
ylabel('P(x), \deltax')
% using a cell array of strings puts one cell per line
title({'P(x)=Ax/(h+x) and \deltax, intersections are steady states' 
       param_string})

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 2. Plot dx/dt = Px/(h+x) - delta*x 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plots to go on figure(2)
figure(2)
plot(x,dxdt(x),'k-','linewidth',2)
grid on
% the steady state should be at (xss,0)
plot(xss,0,'*','markersize',10)
% set the axes labels to be larger
set(gca,'fontsize',16)
% add some axes labels
xlabel('x')
ylabel('dx/dt')
title({'dx/dt=P(x)-\deltax=Ax/(h+x)-\deltax' param_string},'fontsize',16)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3. Simulate the system 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% solve the problem using ODE45
% this is the range of time to simulate for
tspan = [0 20];
% this is a set of initial values of the state
x0s = 0.05:0.1:2;
% plots to go on figure(3)
figure(3)
% loop through the set of initial values, simulating and plotting each case
for x0=x0s
    [t,x] = ode45(@dxdtode,tspan,x0);
    plot(t,x,'linewidth',1)
    hold on
end
% add some labels
xlabel('time, t','fontsize',16);
ylabel('solution, x(t)','fontsize',16);
title({'Simulation of dx/dt=Ax/(h+x)-\deltax' param_string},'fontsize',16)

end
