function hillmultid
% HILLMULTID.M
%
% Code to study dx/dt = Ax^n/(h^n+x^n) - delta*x 
%
% First three subfunctions are defined which can see the 
% parameters in the enclosing function HILL. 
% Then the graphs are plotted and numerical simulations carried out. 
%
% QUESTION: What happens as you increase delta? 
% This version uses a loop over a set of values of delta. 

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % function defining Ax/(h+x)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    function Pfun = P(x)
        Pfun = A*x.^n./(h^n+x.^n);
    end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % function defining dx/dt 
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    function f = dxdt(x)
        f = P(x) - delta*x;
    end

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % function defining dx/dt 
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    function f = dxdtode(t,x)
        f = dxdt(x);
    end

% initialise parameters and the range of x
xmin = 0;
xmax = 1.2;
tmax = 60;
A = 1;
h = 0.5;
delta = 0.999;
n = 2;
% instead, specify five values of delta to loop over
deltas = [0.5 0.75 0.99 1.01 1.5];
% generate a string containing the parameter values for figures
param_string = sprintf('A=%g, h=%g, n=%d, \\delta=[%g,%g,%g,%g,%g]',A,h,n,deltas);

% initialise figure(1)
figure(1), clf, hold on
% refine the axis
axis([xmin xmax 0 1.1])
% initialise figure(2)
figure(2), clf, hold on
% refine the axis
axis([xmin xmax -0.2 0.2])
% initialise figure(3)
figure(3), clf, hold on
axis([0 tmax 0 2])

% specify five line colours, one for each value of delta
mycol = {'r' 'g' 'b' 'c' 'm'};
% loop over the values for delta - use an index i so we can use it to
% specify a line colour mycol{i}
for i=1:length(deltas)
	delta = deltas(i);
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % steady states are where dx/dt = 0
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    xss = fzero(@dxdt,1);

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % 1. Plot P(x)
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % set up a vector of x values 
    x = xmin:0.01:xmax;
    % plots to go on figure(1)
    figure(1)
    % plot Px/(h+x)
    plot(x,P(x),'k-','linewidth',2)
    % Superimpose delta*x
    plot(x,delta*x,mycol{i},'linewidth',1)
    % the intersection should be at (xss,P(xss))
    plot(xss,P(xss),'*','markersize',10)
    % set the axes labels to be larger
    set(gca,'fontsize',14)
    % add some axes labels
    xlabel('x')
    ylabel('P(x), \deltax')
    % using a cell array of strings puts one cell per line
    title({'P(x)=Ax/(h+x) and \deltax, intersections are steady states' 
           param_string})

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % 2. Plot dx/dt = Px/(h+x) - delta*x 
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % plots to go on figure(2)
    figure(2)
    plot(x,dxdt(x),mycol{i},'linewidth',1)
    grid on
    % the steady state should be at (xss,0)
    plot(xss,0,'*','markersize',10)
    % set the axes labels to be larger
    set(gca,'fontsize',16)
    % add some axes labels
    xlabel('x')
    ylabel('dx/dt')
    title({'dx/dt=P(x)-\deltax=Ax/(h+x)-\deltax' param_string},'fontsize',16)

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % 3. Simulate the system 
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % solve the problem using ODE45
    % this is the range of time to simulate for
    tspan = [0 tmax];
    % this is a set of initial values of the state
    x0s = 0.001:0.1:2;
    % plots to go on figure(3)
    figure(3)
    % loop through the set of initial values, simulating and plotting each case
    for x0=x0s
        [t,x] = ode45(@dxdtode,tspan,x0);
        plot(t,x,mycol{i},'linewidth',1)
        hold on
    end
    % add some labels
    xlabel('time, t','fontsize',16);
    ylabel('solution, x(t)','fontsize',16);
    title({'Simulation of dx/dt=Ax/(h+x)-\deltax' param_string},'fontsize',16)
end

end
